Module blaxel.core.sandbox.client.models.file_with_content
==========================================================

Classes
-------

`FileWithContent(content: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, group: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, last_modified: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, name: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, owner: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, path: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, permissions: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, size: blaxel.core.sandbox.client.types.Unset | int = <blaxel.core.sandbox.client.types.Unset object>)`
:   Attributes:
        content (Union[Unset, str]):
        group (Union[Unset, str]):
        last_modified (Union[Unset, str]):
        name (Union[Unset, str]):
        owner (Union[Unset, str]):
        path (Union[Unset, str]):
        permissions (Union[Unset, str]):
        size (Union[Unset, int]):
    
    Method generated by attrs for class FileWithContent.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `content: blaxel.core.sandbox.client.types.Unset | str`
    :

    `group: blaxel.core.sandbox.client.types.Unset | str`
    :

    `last_modified: blaxel.core.sandbox.client.types.Unset | str`
    :

    `name: blaxel.core.sandbox.client.types.Unset | str`
    :

    `owner: blaxel.core.sandbox.client.types.Unset | str`
    :

    `path: blaxel.core.sandbox.client.types.Unset | str`
    :

    `permissions: blaxel.core.sandbox.client.types.Unset | str`
    :

    `size: blaxel.core.sandbox.client.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :